# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/10_attr.ipynb.

# %% auto 0
__all__ = ['hasshape', 'hascolumns', 'hasdf', 'hasindex']

# %% ../nbs/10_attr.ipynb 4
from typing import TypeGuard
from typing import Callable

# %% ../nbs/10_attr.ipynb 5
from .core import make

# %% ../nbs/10_attr.ipynb 7
@make('shape')
def hasshape(obj) -> TypeGuard[Callable]: '''Checks if `obj.shape` exists'''

@make('columns')
def hascolumns(obj) -> TypeGuard[Callable]: '''Checks if `obj.columns` exists'''

@make('df')
def hasdf(obj) -> TypeGuard[Callable]: '''Checks if `obj.df` exists'''

@make('index')
def hasindex(obj) -> TypeGuard[Callable]: '''Checks if `obj.index` exists'''
