# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/hasr',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/hasr',
                'lib_path': 'hasr'},
  'syms': { 'hasr.attr': { 'hasr.attr.hascolumns': ('attr.html#hascolumns', 'hasr/attr.py'),
                           'hasr.attr.hasdf': ('attr.html#hasdf', 'hasr/attr.py'),
                           'hasr.attr.hasindex': ('attr.html#hasindex', 'hasr/attr.py'),
                           'hasr.attr.hasshape': ('attr.html#hasshape', 'hasr/attr.py')},
            'hasr.atyp': {},
            'hasr.call': { 'hasr.call.hasget': ('call.html#hasget', 'hasr/call.py'),
                           'hasr.call.haskeys': ('call.html#haskeys', 'hasr/call.py')},
            'hasr.core': { 'hasr.core.hasr': ('core.html#hasr', 'hasr/core.py'),
                           'hasr.core.make': ('core.html#make', 'hasr/core.py'),
                           'hasr.core.name': ('core.html#name', 'hasr/core.py'),
                           'hasr.core.qual': ('core.html#qual', 'hasr/core.py')},
            'hasr.lens': { 'hasr.lens.aopn': ('lens.html#aopn', 'hasr/lens.py'),
                           'hasr.lens.has1': ('lens.html#has1', 'hasr/lens.py'),
                           'hasr.lens.has2': ('lens.html#has2', 'hasr/lens.py'),
                           'hasr.lens.has3': ('lens.html#has3', 'hasr/lens.py'),
                           'hasr.lens.has4': ('lens.html#has4', 'hasr/lens.py'),
                           'hasr.lens.hasn': ('lens.html#hasn', 'hasr/lens.py'),
                           'hasr.lens.lenn': ('lens.html#lenn', 'hasr/lens.py'),
                           'hasr.lens.trylen': ('lens.html#trylen', 'hasr/lens.py')}}}
