# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/20_call.ipynb.

# %% auto 0
__all__ = ['hasget', 'haskeys']

# %% ../nbs/20_call.ipynb 4
from typing import TypeGuard
from typing import Callable

# %% ../nbs/20_call.ipynb 5
from .core import make

# %% ../nbs/20_call.ipynb 7
@make('get', guard=callable)
def hasget(obj) -> TypeGuard[Callable]:
    '''Checks if `obj.get` is a callable'''


@make('keys', guard=callable)
def haskeys(obj) -> TypeGuard[Callable]: 
    '''Checks if `obj.keys` is a callable'''
