# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_atyp.ipynb.

# %% auto 0
__all__ = ['P', 'R', 'Operator']

# %% ../nbs/00_atyp.ipynb 4
from types import BuiltinFunctionType
from typing import Callable, Union, TypeAlias, ParamSpec, TypeVar, TypeGuard

# %% ../nbs/00_atyp.ipynb 6
P = ParamSpec('P')
R = TypeVar('R', bound=Callable[..., TypeGuard[object]])

# %% ../nbs/00_atyp.ipynb 7
Operator: TypeAlias = Union[BuiltinFunctionType, Callable]
